@@ -49,6 +49,7 @@
 
 package com.openexchange.mobile.api.facade.configuration;
 
+import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.Map;
@@ -107,10 +108,16 @@ public class HostConfiguration {
 
     /*private*/ public static final String FORWARD_HOST_HEADER = "com.openexchange.mobile.api.facade.forwardHostHeader";
 
+    /*private*/ public static final String CUSTOM_PROPERTIES = "customProperties";
+
+    /*private*/ public static final String MATCHES = "matches";
+
     String authenticationClassName;
 
     Map<String, String> minimumClientVersions = new Hashtable<>();
 
+    Map<String, String> customProperties = new HashMap<>();
+
     ThreadingType threadingType;
 
     String numMailsPerFolder;
@@ -258,6 +265,18 @@ public class HostConfiguration {
                 }
                 continue;
 
+            case CUSTOM_PROPERTIES:
+                @SuppressWarnings("unchecked")
+                Map<String, Object> map = (Map<String, Object>) propertyValue;
+                for (Map.Entry<String, Object> customPropertyEntry : map.entrySet()) {
+                    customProperties.put(customPropertyEntry.getKey(), customPropertyEntry.getValue().toString());
+                }
+                continue;
+
+            // Ignore. Will be handled by MatchingHostConfiguration subclass.
+            case MATCHES:
+                continue;
+
             default:
                 log.warn("Unrecognized configuration property '" + propertyName + "'");
                 continue;
